#!/bin/sh

################################################################################

clear

backup_path=$PATH

dirbld_root=~/Development

dirsrc_binutils=binutils-2.19.51
dirbld_binutils=binutils-2.19.51_build_lin
dirsrc_gcc=gcc-4.4.0
dirbld_gcc=gcc-4.4.0_build_lin
dirsrc_newlib=newlib-1.17.0
dirbld_newlib=newlib-1.17.0_build_lin

dirsrc_gmp=gmp-4.3.1
dirbld_gmp=gmp-4.3.1_build
dirsrc_mpfr=mpfr-2.4.1
dirbld_mpfr=mpfr-2.4.1_build

rplace_newlib_iput='CFLAGS_FOR_TARGET = -g -Os'
rplace_newlib_oput='CFLAGS_FOR_TARGET = -g -Os -DREENTRANT_SYSCALLS_PROVIDED -DINTEGER_ONLY'

#build=i686-linux-gnu
#host=i586-mingw32msvc
host=i686-linux-gnu
target=arm-elf
prefix=$dirbld_root/__gcc_arm_elf_lin

################################################################################

cp --recursive $dirsrc_newlib/newlib $dirsrc_gcc/newlib
cp --recursive $dirsrc_gmp           $dirsrc_gcc/gmp
cp --recursive $dirsrc_mpfr          $dirsrc_gcc/mpfr

################################################################################

export CFLAGS='-O2 -pipe'
export CXXFLAGS='-O2 -pipe'

##### BINUTILS #################################################################

mkdir $dirbld_binutils
cd $dirbld_binutils
date
pwd

../$dirsrc_binutils/configure --build=$build --host=$host --target=$target --prefix=$prefix \
--with-gcc --with-gnu-ld --with-gnu-as --with-float=soft                                    \
--disable-nls --disable-shared --disable-debug --disable-threads	                        \
--disable-win32-registry --disable-interwork --disable-multilib		                        \
> __01_cnfg.log 2>&1

make         > __02_make_all.log     2>&1
make install > __03_make_install.log 2>&1

cd ..

################################################################################

PATH=$prefix/bin:$PATH
export PATH

##### GCC PART 01 ##############################################################

mkdir $dirbld_gcc
cd $dirbld_gcc
date
pwd

../$dirsrc_gcc/configure --build=$build --host=$host --target=$target --prefix=$prefix	\
--disable-nls --disable-shared --disable-threads --disable-win32-registry       	    \
--with-newlib --with-headers=$dirbld_root/$dirsrc_newlib/newlib/libc/include		    \
--with-dwarf2 --with-float=soft --disable-interwork --disable-multilib          	    \
--with-cpu=arm7tdmi --with-gcc --with-gnu-ld --with-gnu-as                              \
--disable-libssp --disable-libstdcxx-pch --disable-libmudflap --disable-libgomp 	    \
--enable-languages=c,c++                                                        	    \
-v                                                                              	    \
> __01_make_cnfg_gcc.log 2>&1

make all-gcc     > __02_make_all_gcc.log     2>&1
make install-gcc > __03_make_install_gcc.log 2>&1

ln -s $prefix/bin/$target-gcc $prefix/bin/$target-cc

cd ..

##### NEWLIB ###################################################################

mkdir $dirbld_newlib
cd $dirbld_newlib
date
pwd

../$dirsrc_newlib/configure --build=$build --host=$host --target=$target --prefix=$prefix	\
--disable-newlib-supplied-syscalls --disable-interwork --disable-multilib  			\
> __01_cnfg.log 2>&1

mv Makefile Makefile.org
sed -e "s/$rplace_newlib_iput/$rplace_newlib_oput/" Makefile.org > Makefile

make         > __02_make_all.log     2>&1
make install > __03_make_install.log 2>&1

cd ..

##### GCC PART 02 ##############################################################

cd $dirbld_gcc
date
pwd

make         > __04_make_all.log     2>&1
make install > __05_make_install.log 2>&1

cd ..

################################################################################

PATH=$backup_path
export PATH

date

################################################################################

rm --recursive --force $dirsrc_gcc/newlib
rm --recursive --force $dirsrc_gcc/gmp
rm --recursive --force $dirsrc_gcc/mpfr
